@@ -23,11 +23,10 @@
 
 #include <QFile>
 #include <QProcess>
-#include <KService>
 
 using namespace KFileMetaData;
 
-OfficeExtractor::OfficeExtractor(QObject* parent, const QVariantList&)
+OfficeExtractor::OfficeExtractor(QObject* parent)
     : ExtractorPlugin(parent)
 {
     // Find the executables of catdoc, catppt and xls2csv. If an executable cannot
@@ -58,15 +57,15 @@ void OfficeExtractor::extract(ExtractionResult* result)
     QStringList args;
     QString contents;
 
-    args << QLatin1String("-s") << QLatin1String("cp1252"); // FIXME: Store somewhere a map between the user's language and the encoding of the Windows files it may use ?
-    args << QLatin1String("-d") << QLatin1String("utf8");
+    args << QStringLiteral("-s") << QStringLiteral("cp1252"); // FIXME: Store somewhere a map between the user's language and the encoding of the Windows files it may use ?
+    args << QStringLiteral("-d") << QStringLiteral("utf8");
 
     const QString fileUrl = result->inputUrl();
     const QString mimeType = result->inputMimetype();
-    if (mimeType == QLatin1String("application/msword")) {
+    if (mimeType == QStringLiteral("application/msword")) {
         result->addType(Type::Document);
 
-        args << QLatin1String("-w");
+        args << QStringLiteral("-w");
         contents = textFromFile(fileUrl, m_catdoc, args);
 
         // Now that we have the plain text content, count words, lines and characters
@@ -76,15 +75,15 @@ void OfficeExtractor::extract(ExtractionResult* result)
 
         result->add(Property::WordCount, words);
         result->add(Property::LineCount, lines);
-    } else if (mimeType == QLatin1String("application/vnd.ms-excel")) {
+    } else if (mimeType == QStringLiteral("application/vnd.ms-excel")) {
         result->addType(Type::Document);
         result->addType(Type::Spreadsheet);
 
-        args << QLatin1String("-c") << QLatin1String(" ");
-        args << QLatin1String("-b") << QLatin1String(" ");
-        args << QLatin1String("-q") << QLatin1String("0");
+        args << QStringLiteral("-c") << QStringLiteral(" ");
+        args << QStringLiteral("-b") << QStringLiteral(" ");
+        args << QStringLiteral("-q") << QStringLiteral("0");
         contents = textFromFile(fileUrl, m_xls2csv, args);
-    } else if (mimeType == QLatin1String("application/vnd.ms-powerpoint")) {
+    } else if (mimeType == QStringLiteral("application/vnd.ms-powerpoint")) {
         result->addType(Type::Document);
         result->addType(Type::Presentation);
 
@@ -115,7 +114,3 @@ QString OfficeExtractor::textFromFile(const QString& fileUrl, const QString& com
     else
         return QString::fromUtf8(process.readAll());
 }
-
-K_PLUGIN_FACTORY(factory, registerPlugin<OfficeExtractor>();)
-
-#include "officeextractor.moc"
