@@ -229,8 +229,19 @@ enum Property {
     PhotoISOSpeedRatings,
     PhotoSaturation,
     PhotoSharpness,
+    PhotoGpsLatitude,
+    PhotoGpsLongitude,
+    PhotoGpsAltitude,
 
-    LastProperty = PhotoSharpness
+    TranslationUnitsTotal,
+    TranslationUnitsWithTranslation,
+    TranslationUnitsWithDraftTranslation,
+    TranslationLastAuthor,
+    TranslationLastUpDate,
+    TranslationTemplateDate,
+
+    PropertyCount,
+    LastProperty = PropertyCount-1
 };
 
 } // namespace Property
